==> ted_2.11.orig.tar.gz: Ted-2.11/Ted/docRtfShapeEnum.h <==
/************************************************************************/
/*									*/
/* Enum to describe the different shape properties.			*/
/*									*/
/************************************************************************/

typedef enum ShapeProperty
    {
    RTFSHP_Rotation,
    RTFSHP_fFlipV,
    RTFSHP_fFlipH,
    RTFSHP_shapeType,
    RTFSHP_WzName,
    RTFSHP_pWrapPolygonVertices,
    RTFSHP_dxWrapDistLeft,
    RTFSHP_dyWrapDistTop,
    RTFSHP_dxWrapDistRight,
    RTFSHP_dyWrapDistBottom,
    RTFSHP_fBehindDocument,
    RTFSHP_fIsButton,
    RTFSHP_fHidden,
    RTFSHP_fLockRotation,
    RTFSHP_fLockAspectRatio,
    RTFSHP_fLockAgainstSelect,
    RTFSHP_fLockCropping,
    RTFSHP_fLockVerticies,
    RTFSHP_fLockText,
    RTFSHP_fLockAdjustHandles,
    RTFSHP_fLockAgainstGrouping,
    RTFSHP_dxTextLeft,
    RTFSHP_dyTextTop,
    RTFSHP_dxTextRight,
    RTFSHP_dyTextBottom,
    RTFSHP_WrapText,
    RTFSHP_anchorText,
    RTFSHP_txflTextFlow,
    RTFSHP_gtextUNICODE,
    RTFSHP_gtextAlign,
    RTFSHP_gtextSize,
    RTFSHP_gtextSpacing,
    RTFSHP_gtextFont,
    RTFSHP_fGtext,
    RTFSHP_gtextFVertical,
    RTFSHP_gtextFKern,
    RTFSHP_gtextFTight,
    RTFSHP_gtextFStretch,
    RTFSHP_gtextFShrinkFit,
    RTFSHP_gtextFBestFit,
    RTFSHP_gtextFNormalize,
    RTFSHP_gtextFDxMeasure,
    RTFSHP_gtextFBold,
    RTFSHP_gtextFItalic,
    RTFSHP_gtextFUnderline,
    RTFSHP_gtextFShadow,
    RTFSHP_gtextFSmallcaps,
    RTFSHP_gtextFStrikethrough,
    RTFSHP_cropFromTop,
    RTFSHP_cropFromBottom,
    RTFSHP_cropFromLeft,
    RTFSHP_cropFromRight,
    RTFSHP_pib,
    RTFSHP_pibName,
    RTFSHP_pibFlags,
    RTFSHP_pictureTransparent,
    RTFSHP_pictureContrast,
    RTFSHP_PictureBrightness,
    RTFSHP_pictureGamma,
    RTFSHP_pictureGray,
    RTFSHP_pictureBiLevel,
    RTFSHP_geoLeft,
    RTFSHP_geoTop,
    RTFSHP_geoRight,
    RTFSHP_geoBottom,
    RTFSHP_pVerticies,
    RTFSHP_pSegmentInfo,
    RTFSHP_adjustValue,
    RTFSHP_adjust2Value,
    RTFSHP_adjust3Value,
    RTFSHP_adjust4Value,
    RTFSHP_adjust5Value,
    RTFSHP_adjust6Value,
    RTFSHP_adjust7Value,
    RTFSHP_adjust8Value,
    RTFSHP_adjust9Value,
    RTFSHP_adjust10Value,
    RTFSHP_fillType,
    RTFSHP_fillColor,
    RTFSHP_fillOpacity,
    RTFSHP_fillBackColor,
    RTFSHP_fillBackOpacity,
    RTFSHP_fillBlip,
    RTFSHP_fillBlipName,
    RTFSHP_fillblipflags,
    RTFSHP_fillWidth,
    RTFSHP_fillHeight,
    RTFSHP_fillAngle,
    RTFSHP_fillFocus,
    RTFSHP_fillToLeft,
    RTFSHP_fillToTop,
    RTFSHP_fillToRight,
    RTFSHP_fillToBottom,
    RTFSHP_fillShadeColors,
    RTFSHP_fillOriginX,
    RTFSHP_fillOriginY,
    RTFSHP_fillShapeOriginX,
    RTFSHP_fillShapeOriginY,
    RTFSHP_fillCrMod,
    RTFSHP_fillBlipFlags,
    RTFSHP_fillRectLeft,
    RTFSHP_fillRectTop,
    RTFSHP_fillRectRight,
    RTFSHP_fillRectBottom,
    RTFSHP_fillDztype,
    RTFSHP_fillShadePreset,
    RTFSHP_fFilled,
    RTFSHP_lineColor,
    RTFSHP_lineBackColor,
    RTFSHP_lineType,
    RTFSHP_lineFillBlip,
    RTFSHP_lineblipflags,
    RTFSHP_lineFillWidth,
    RTFSHP_lineFillHeight,
    RTFSHP_lineFillDztype,
    RTFSHP_lineWidth,
    RTFSHP_lineStyle,
    RTFSHP_lineDashing,
    RTFSHP_lineStartArrowhead,
    RTFSHP_lineEndArrowhead,
    RTFSHP_lineStartArrowWidth,
    RTFSHP_lineStartArrowLength,
    RTFSHP_lineEndArrowWidth,
    RTFSHP_lineEndArrowLength,
    RTFSHP_lineCrMod,
    RTFSHP_lineFillBlipFlags,
    RTFSHP_lineMiterLimit,
    RTFSHP_fLine,
    RTFSHP_shadowType,
    RTFSHP_shadowColor,
    RTFSHP_shadowHighlight,
    RTFSHP_shadowOpacity,
    RTFSHP_shadowOffsetX,
    RTFSHP_shadowOffsetY,
    RTFSHP_shadowSecondOffsetX,
    RTFSHP_shadowSecondOffsetY,
    RTFSHP_shadowScaleXToX,
    RTFSHP_shadowScaleYToX,
    RTFSHP_shadowScaleXToY,
    RTFSHP_shadowScaleYToY,
    RTFSHP_shadowPerspectiveX,
    RTFSHP_shadowPerspectiveY,
    RTFSHP_shadowWeight,
    RTFSHP_shadowOriginX,
    RTFSHP_shadowOriginY,
    RTFSHP_shadowCrMod,
    RTFSHP_fShadow,
    RTFSHP_c3DSpecularAmt,
    RTFSHP_c3DDiffuseAmt,
    RTFSHP_c3DShininess,
    RTFSHP_c3DEdgeThickness,
    RTFSHP_c3DExtrudeForward,
    RTFSHP_c3DExtrudeBackward,
    RTFSHP_c3DExtrusionColor,
    RTFSHP_f3D,
    RTFSHP_fc3DMetallic,
    RTFSHP_fc3DUseExtrusionColor,
    RTFSHP_fc3DLightFace,
    RTFSHP_c3DYRotationAngle,
    RTFSHP_c3DXRotationAngle,
    RTFSHP_c3DRotationAxisX,
    RTFSHP_c3DRotationAxisY,
    RTFSHP_c3DRotationAxisZ,
    RTFSHP_c3DRotationAngle,
    RTFSHP_fC3DRotationCenterAut,
    RTFSHP_c3DRotationCenterX,
    RTFSHP_c3DRotationCenterY,
    RTFSHP_c3DRotationCenterZ,
    RTFSHP_c3DRenderMode,
    RTFSHP_c3DXViewpoint,
    RTFSHP_c3DYViewpoint,
    RTFSHP_c3DZViewpoint,
    RTFSHP_c3DOriginX,
    RTFSHP_c3DOriginY,
    RTFSHP_c3DSkewAngle,
    RTFSHP_c3DSkewAmount,
    RTFSHP_c3DAmbientIntensity,
    RTFSHP_c3DKeyX,
    RTFSHP_c3DKeyY,
    RTFSHP_c3DKeyZ,
    RTFSHP_c3DKeyIntensity,
    RTFSHP_c3DFillX,
    RTFSHP_c3DFillY,
    RTFSHP_c3DFillZ,
    RTFSHP_c3DFillIntensity,
    RTFSHP_c3DExtrudePlane,
    RTFSHP_c3DCrMod,
    RTFSHP_c3DTolerance,
    RTFSHP_fc3DParallel,
    RTFSHP_fc3DKeyHarsh,
    RTFSHP_fc3DFillHarsh,
    RTFSHP_fc3DConstrainRotation,	/*  ?  */
    RTFSHP_fc3DRotationCenterAuto,	/*  ?  */
    RTFSHP_spcot,
    RTFSHP_dxyCalloutGap,
    RTFSHP_spcoa,
    RTFSHP_spcod,
    RTFSHP_dxyCalloutDropSpecified,
    RTFSHP_dxyCalloutLengthSpecified,
    RTFSHP_fCallout,
    RTFSHP_fCalloutAccentBar,
    RTFSHP_fCalloutTextBorder,
    RTFSHP_fCalloutDropAuto,
    RTFSHP_fCalloutLengthSpecified,

    RTFSHP_pictureId,
    RTFSHP_pictureActive,
    RTFSHP_fHitTestFill,
    RTFSHP_fillShape,
    RTFSHP_fillUseRect,
    RTFSHP_fNoFillHitTest,
    RTFSHP_fArrowheadsOK,
    RTFSHP_fHitTestLine,
    RTFSHP_lineFillShape,
    RTFSHP_fNoLineDrawDash,
    RTFSHP_fshadowObscured,
    RTFSHP_fEditedWrap,
    RTFSHP_fOnDblClickNotify,
    RTFSHP_fOneD,
    RTFSHP_fPrint,

    RTFSHP_groupLeft,		/* ? */
    RTFSHP_groupTop,		/* ? */
    RTFSHP_groupRight,		/* ? */
    RTFSHP_groupBottom,		/* ? */

    RTFSHP_relLeft,		/* ? */
    RTFSHP_relTop,		/* ? */
    RTFSHP_relRight,		/* ? */
    RTFSHP_relBottom,		/* ? */

    RTFSHP_fRelFlipH,		/* ? */
    RTFSHP_fRelFlipV,		/* ? */

    RTFSHP_pictureDblCrMod,	/* ? */
    RTFSHP_pictureFillCrMod,	/* ? */
    RTFSHP_pictureLineCrMod,	/* ? */
    RTFSHP_fillShadeType,	/* ? */
    RTFSHP_fSelectText,		/* ? */
    RTFSHP_fRotateText,		/* ? */
    RTFSHP_fFitShapeToText,	/* ? */
    RTFSHP_fFitTextToShape,	/* ? */
    RTFSHP_fAutoTextMargin,	/* ? */
    RTFSHP_fCalloutMinusX,	/* ? */
    RTFSHP_fCalloutMinusY,	/* ? */

    RTFSHP_shapePath,		/* ? */
    RTFSHP_fFillOK,		/* ? */
    RTFSHP_lTxid,		/* ? */
    RTFSHP_hspNext,		/* ? */
    RTFSHP_lidRegroup,		/* ? */

    RTFSHP_lineOpacity,		/* ? */
    RTFSHP_lineEndCapStyle,	/* ? */

    RTFSHP_rotation,		/* ? */
    RTFSHP_cdirFont,		/* ? */
    RTFSHP_bWMode,
    RTFSHP_fLayoutInCell,

    RTFSHP__________Terminate_Enum
    } ShapeProperty;

==> ted_2.16.orig.tar.gz: Ted-2.16/Ted/docRtfShapeEnum.h <==
/************************************************************************/
/*									*/
/* Enum to describe the different shape properties.			*/
/*									*/
/************************************************************************/

typedef enum ShapePropertyId
    {
    RTFSHP_Rotation,
    RTFSHP_posv,
    RTFSHP_posh,
    RTFSHP_posrelv,
    RTFSHP_posrelh,
    RTFSHP_fFlipV,
    RTFSHP_fFlipH,
    RTFSHP_shapeType,
    RTFSHP_WzName,
    RTFSHP_pWrapPolygonVertices,
    RTFSHP_dxWrapDistLeft,
    RTFSHP_dyWrapDistTop,
    RTFSHP_dxWrapDistRight,
    RTFSHP_dyWrapDistBottom,
    RTFSHP_fBehindDocument,
    RTFSHP_fIsButton,
    RTFSHP_fHidden,
    RTFSHP_fLockRotation,
    RTFSHP_fLockAspectRatio,
    RTFSHP_fLockAgainstSelect,
    RTFSHP_fLockCropping,
    RTFSHP_fLockVerticies,
    RTFSHP_fLockText,
    RTFSHP_fLockAdjustHandles,
    RTFSHP_fLockAgainstGrouping,
    RTFSHP_dxTextLeft,
    RTFSHP_dyTextTop,
    RTFSHP_dxTextRight,
    RTFSHP_dyTextBottom,
    RTFSHP_WrapText,
    RTFSHP_anchorText,
    RTFSHP_txflTextFlow,
    RTFSHP_gtextUNICODE,
    RTFSHP_gtextAlign,
    RTFSHP_gtextSize,
    RTFSHP_gtextSpacing,
    RTFSHP_gtextFont,
    RTFSHP_fGtext,
    RTFSHP_gtextFVertical,
    RTFSHP_gtextFKern,
    RTFSHP_gtextFTight,
    RTFSHP_gtextFStretch,
    RTFSHP_gtextFShrinkFit,
    RTFSHP_gtextFBestFit,
    RTFSHP_gtextFNormalize,
    RTFSHP_gtextFDxMeasure,
    RTFSHP_gtextFBold,
    RTFSHP_gtextFItalic,
    RTFSHP_gtextFUnderline,
    RTFSHP_gtextFShadow,
    RTFSHP_gtextFSmallcaps,
    RTFSHP_gtextFStrikethrough,
    RTFSHP_cropFromTop,
    RTFSHP_cropFromBottom,
    RTFSHP_cropFromLeft,
    RTFSHP_cropFromRight,
    RTFSHP_pib,
    RTFSHP_pibName,
    RTFSHP_pibFlags,
    RTFSHP_pictureTransparent,
    RTFSHP_pictureContrast,
    RTFSHP_pictureBrightness,
    RTFSHP_pictureGamma,
    RTFSHP_pictureGray,
    RTFSHP_pictureBiLevel,
    RTFSHP_geoLeft,
    RTFSHP_geoTop,
    RTFSHP_geoRight,
    RTFSHP_geoBottom,
    RTFSHP_pVerticies,
    RTFSHP_pSegmentInfo,
    RTFSHP_adjustValue,
    RTFSHP_adjust2Value,
    RTFSHP_adjust3Value,
    RTFSHP_adjust4Value,
    RTFSHP_adjust5Value,
    RTFSHP_adjust6Value,
    RTFSHP_adjust7Value,
    RTFSHP_adjust8Value,
    RTFSHP_adjust9Value,
    RTFSHP_adjust10Value,
    RTFSHP_fillType,
    RTFSHP_fillColor,
    RTFSHP_fillOpacity,
    RTFSHP_fillBackColor,
    RTFSHP_fillBackOpacity,
    RTFSHP_fillBlip,
    RTFSHP_fillBlipName,
    RTFSHP_fillblipflags,
    RTFSHP_fillWidth,
    RTFSHP_fillHeight,
    RTFSHP_fillAngle,
    RTFSHP_fillFocus,
    RTFSHP_fillToLeft,
    RTFSHP_fillToTop,
    RTFSHP_fillToRight,
    RTFSHP_fillToBottom,
    RTFSHP_fillShadeColors,
    RTFSHP_fillOriginX,
    RTFSHP_fillOriginY,
    RTFSHP_fillShapeOriginX,
    RTFSHP_fillShapeOriginY,
    RTFSHP_fillCrMod,
    RTFSHP_fillBlipFlags,
    RTFSHP_fillRectLeft,
    RTFSHP_fillRectTop,
    RTFSHP_fillRectRight,
    RTFSHP_fillRectBottom,
    RTFSHP_fillDztype,
    RTFSHP_fillShadePreset,
    RTFSHP_fFilled,
    RTFSHP_lineColor,
    RTFSHP_lineBackColor,
    RTFSHP_lineType,
    RTFSHP_lineFillBlip,
    RTFSHP_lineblipflags,
    RTFSHP_lineFillWidth,
    RTFSHP_lineFillHeight,
    RTFSHP_lineFillDztype,
    RTFSHP_lineWidth,
    RTFSHP_lineStyle,
    RTFSHP_lineDashing,
    RTFSHP_lineStartArrowhead,
    RTFSHP_lineEndArrowhead,
    RTFSHP_lineStartArrowWidth,
    RTFSHP_lineStartArrowLength,
    RTFSHP_lineEndArrowWidth,
    RTFSHP_lineEndArrowLength,
    RTFSHP_lineCrMod,
    RTFSHP_lineFillBlipFlags,
    RTFSHP_lineMiterLimit,
    RTFSHP_fLine,
    RTFSHP_shadowType,
    RTFSHP_shadowColor,
    RTFSHP_shadowHighlight,
    RTFSHP_shadowOpacity,
    RTFSHP_shadowOffsetX,
    RTFSHP_shadowOffsetY,
    RTFSHP_shadowSecondOffsetX,
    RTFSHP_shadowSecondOffsetY,
    RTFSHP_shadowScaleXToX,
    RTFSHP_shadowScaleYToX,
    RTFSHP_shadowScaleXToY,
    RTFSHP_shadowScaleYToY,
    RTFSHP_shadowPerspectiveX,
    RTFSHP_shadowPerspectiveY,
    RTFSHP_shadowWeight,
    RTFSHP_shadowOriginX,
    RTFSHP_shadowOriginY,
    RTFSHP_shadowCrMod,
    RTFSHP_fShadow,
    RTFSHP_c3DSpecularAmt,
    RTFSHP_c3DDiffuseAmt,
    RTFSHP_c3DShininess,
    RTFSHP_c3DEdgeThickness,
    RTFSHP_c3DExtrudeForward,
    RTFSHP_c3DExtrudeBackward,
    RTFSHP_c3DExtrusionColor,
    RTFSHP_f3D,
    RTFSHP_fc3DMetallic,
    RTFSHP_fc3DUseExtrusionColor,
    RTFSHP_fc3DLightFace,
    RTFSHP_c3DYRotationAngle,
    RTFSHP_c3DXRotationAngle,
    RTFSHP_c3DRotationAxisX,
    RTFSHP_c3DRotationAxisY,
    RTFSHP_c3DRotationAxisZ,
    RTFSHP_c3DRotationAngle,
    RTFSHP_fC3DRotationCenterAut,
    RTFSHP_c3DRotationCenterX,
    RTFSHP_c3DRotationCenterY,
    RTFSHP_c3DRotationCenterZ,
    RTFSHP_c3DRenderMode,
    RTFSHP_c3DXViewpoint,
    RTFSHP_c3DYViewpoint,
    RTFSHP_c3DZViewpoint,
    RTFSHP_c3DOriginX,
    RTFSHP_c3DOriginY,
    RTFSHP_c3DSkewAngle,
    RTFSHP_c3DSkewAmount,
    RTFSHP_c3DAmbientIntensity,
    RTFSHP_c3DKeyX,
    RTFSHP_c3DKeyY,
    RTFSHP_c3DKeyZ,
    RTFSHP_c3DKeyIntensity,
    RTFSHP_c3DFillX,
    RTFSHP_c3DFillY,
    RTFSHP_c3DFillZ,
    RTFSHP_c3DFillIntensity,
    RTFSHP_c3DExtrudePlane,
    RTFSHP_c3DCrMod,
    RTFSHP_c3DTolerance,
    RTFSHP_fc3DParallel,
    RTFSHP_fc3DKeyHarsh,
    RTFSHP_fc3DFillHarsh,
    RTFSHP_fc3DConstrainRotation,	/*  ?  */
    RTFSHP_fc3DRotationCenterAuto,	/*  ?  */
    RTFSHP_spcot,
    RTFSHP_dxyCalloutGap,
    RTFSHP_spcoa,
    RTFSHP_spcod,
    RTFSHP_dxyCalloutDropSpecified,
    RTFSHP_dxyCalloutLengthSpecified,
    RTFSHP_fCallout,
    RTFSHP_fCalloutAccentBar,
    RTFSHP_fCalloutTextBorder,
    RTFSHP_fCalloutDropAuto,
    RTFSHP_fCalloutLengthSpecified,

    RTFSHP_pictureId,
    RTFSHP_pictureActive,
    RTFSHP_fHitTestFill,
    RTFSHP_fillShape,
    RTFSHP_fillUseRect,
    RTFSHP_fNoFillHitTest,
    RTFSHP_fArrowheadsOK,
    RTFSHP_fHitTestLine,
    RTFSHP_lineFillShape,
    RTFSHP_fNoLineDrawDash,
    RTFSHP_fshadowObscured,
    RTFSHP_fEditedWrap,
    RTFSHP_fOnDblClickNotify,
    RTFSHP_fOneD,
    RTFSHP_fPrint,

    RTFSHP_groupLeft,		/* ? */
    RTFSHP_groupTop,		/* ? */
    RTFSHP_groupRight,		/* ? */
    RTFSHP_groupBottom,		/* ? */

    RTFSHP_relLeft,		/* ? */
    RTFSHP_relTop,		/* ? */
    RTFSHP_relRight,		/* ? */
    RTFSHP_relBottom,		/* ? */

    RTFSHP_fRelFlipH,		/* ? */
    RTFSHP_fRelFlipV,		/* ? */

    RTFSHP_pictureDblCrMod,	/* ? */
    RTFSHP_pictureFillCrMod,	/* ? */
    RTFSHP_pictureLineCrMod,	/* ? */
    RTFSHP_fillShadeType,	/* ? */
    RTFSHP_fSelectText,		/* ? */
    RTFSHP_fRotateText,		/* ? */
    RTFSHP_fFitShapeToText,	/* ? */
    RTFSHP_fFitTextToShape,	/* ? */
    RTFSHP_fAutoTextMargin,	/* ? */
    RTFSHP_fCalloutMinusX,	/* ? */
    RTFSHP_fCalloutMinusY,	/* ? */

    RTFSHP_shapePath,		/* ? */
    RTFSHP_fFillOK,		/* ? */
    RTFSHP_lTxid,		/* ? */
    RTFSHP_hspNext,		/* ? */
    RTFSHP_lidRegroup,		/* ? */

    RTFSHP_lineOpacity,		/* ? */
    RTFSHP_lineEndCapStyle,	/* ? */

    RTFSHP_rotation,		/* ? */
    RTFSHP_cdirFont,		/* ? */
    RTFSHP_bWMode,
    RTFSHP_fLayoutInCell,

    RTFSHP__________Terminate_Enum
    } ShapePropertyId;
